# Generated by Django 3.1.1 on 2021-02-02 13:22

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("appchance_redlink", "0001_initial"),
    ]

    operations = [
        migrations.DeleteModel(name="DeviceNotificationSettings",),
    ]
